from django.apps import AppConfig


class Djangosaml2SpidConfig(AppConfig):
    name = "djangosaml2_spid"
